@@ -1,23 +1,14 @@
 from __future__ import unicode_literals
 
 import os
+import logging
 
 from mopidy import config, ext
 
-__doc__ = """An extension for playing music from VKontakte.
 
-This extension enables you to play music from VKontakte web service.
+__version__ = '0.2.0'
 
-See https://github.com/sibuser/mopidy-vkontakte for further instructions
-of using this extension.
-
-**Issues:**
-
-https://github.com/sibuser/mopidy-vkontakte/issues
-
-"""
-
-__version__ = '0.1.2'
+logger = logging.getLogger(__name__)
 
 
 class Extension(ext.Extension):
@@ -35,13 +26,8 @@ class Extension(ext.Extension):
         schema['email'] = config.String()
         schema['password'] = config.Secret()
         schema['client_id'] = config.Secret()
-
         return schema
 
-    def validate_config(self, config):
-        if not config.getboolean('vkontakte', 'enabled'):
-            return
-
-    def get_backend_classes(self):
+    def setup(self, registry):
         from .actor import VKBackend
-        return [VKBackend]
+        registry.add('backend', VKBackend)
