@@ -3,30 +3,24 @@ from __future__ import unicode_literals
 import logging
 import pykka
 
-from mopidy.backends import base
+from mopidy import backend
 
 from .library import VKLibraryProvider
 from .playlists import VKPlaylistsProvider
 from .session import VKSession
 
 
-logger = logging.getLogger('mopidy.backends.vkontakte.actor')
+logger = logging.getLogger(__name__)
 
 
-class VKBackend(pykka.ThreadingActor, base.Backend):
+class VKBackend(pykka.ThreadingActor, backend.Backend):
 
     def __init__(self, config, audio):
         super(VKBackend, self).__init__()
         self.config = config
         self.session = VKSession(config=self.config)
         self.library = VKLibraryProvider(backend=self)
-        self.playback = VKPlaybackProvider(audio=audio, backend=self)
+        self.playback = backend.PlaybackProvider(audio=audio, backend=self)
         self.playlists = VKPlaylistsProvider(backend=self)
 
         self.uri_schemes = ['vkontakte']
-
-
-class VKPlaybackProvider(base.BasePlaybackProvider):
-
-    def play(self, track):
-        return super(VKPlaybackProvider, self).play(track)
