@@ -2,16 +2,20 @@ from __future__ import unicode_literals
 
 import logging
 
-from mopidy.backends import base
-# from mopidy.models import SearchResult
+from mopidy import backend, models
 
-logger = logging.getLogger('mopidy.backends.vkontakte.library')
+logger = logging.getLogger(__name__)
 
 
-class VKLibraryProvider(base.BaseLibraryProvider):
+class VKLibraryProvider(backend.LibraryProvider):
     def __init__(self, *args, **kwargs):
         super(VKLibraryProvider, self).__init__(*args, **kwargs)
 
+    root_directory = models.Ref.directory(
+        uri='vkontakte:directory',
+        name='VKontakte'
+    )
+
     def find_exact(self, **query):
         pass
 
